==> greta_0.4.2.tar.gz: greta/tests/testthat/_snaps/distributions.md <==
# uniform distribution errors informatively

    `min` and `max` must be numeric vectors of length 1
    They have class and length:
    `min`: numeric, 1
    `max`: logical, 1

---

    `min` and `max` must be numeric vectors of length 1
    They have class and length:
    `min`: numeric, 1
    `max`: function, 1

---

    `min` and `max` must be numeric vectors of length 1
    They have class and length:
    `min`: integer, 3
    `max`: numeric, 1

---

    `min` and `max` must finite scalars
    Their values are:
    `min`: -Inf
    `max`: Inf

---

    `max` must be greater than `min`
    Their values are:
    `min`: 1
    `max`: 1

# poisson() and binomial() error informatively in glm

    Wrong function name provided in another model
    It looks like you're using greta's `poisson()` function in the family argument of another model.
    Maybe you want to use `` family = stats::`poisson` ``,instead?

---

    Wrong function name provided in another model
    It looks like you're using greta's `binomial()` function in the family argument of another model.
    Maybe you want to use `` family = stats::`binomial` ``,instead?

---

    Wrong function name provided in another model
    It looks like you're using greta's `poisson()` function in the family argument of another model.
    Maybe you want to use `` family = stats::`poisson` ``,instead?

---

    Wrong function name provided in another model
    It looks like you're using greta's `poisson()` function in the family argument of another model.
    Maybe you want to use `` family = stats::`poisson` ``,instead?

# wishart distribution errors informatively

    `Sigma` must be a square 2D greta array
    However, `Sigma` has dimensions
    "3x3x3"

---

    `Sigma` must be a square 2D greta array
    However, `Sigma` has dimensions
    "3x2"

# lkj_correlation distribution errors informatively

    `eta` must be a positive scalar value, or a scalar <greta_array>

---

    `eta` must be a positive scalar value, or a scalar <greta_array>

---

    `eta` must be a scalar
    However `eta` had dimensions: 2, 1

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

# multivariate_normal distribution errors informatively

    the dimension of this distribution must be at least 2, but was 1
    multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    the dimension of this distribution must be at least 2, but was 1
    multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    Dimensions of parameters not compatible with multivariate distribution parameters of multivariate distributions cannot have more than two dimensions
    object `x` has dimensions: 3x3x3

---

    Not 2D square greta array
    x expected a 2D square greta array, but object `x` had dimension: 3x2

---

    distribution dimensions do not match implied dimensions
    The distribution dimension should be 3, but parameters implied dimensions: 3 vs 4
    Multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    the dimension of this distribution must be at least 2, but was 1
    multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    object 'n_realisations' not found

---

    object 'n_realisations' not found

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

# multinomial distribution errors informatively

    the dimension of this distribution must be at least 2, but was 1
    multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    object 'n_realisations' not found

---

    object 'n_realisations' not found

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

# categorical distribution errors informatively

    the dimension of this distribution must be at least 2, but was 1
    multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    object 'n_realisations' not found

---

    object 'n_realisations' not found

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

# dirichlet distribution errors informatively

    the dimension of this distribution must be at least 2, but was 1
    multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    object 'n_realisations' not found

---

    object 'n_realisations' not found

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

# dirichlet-multinomial distribution errors informatively

    the dimension of this distribution must be at least 2, but was 1
    multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    object 'n_realisations' not found

---

    object 'n_realisations' not found

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

==> greta_0.4.5.tar.gz: greta/tests/testthat/_snaps/distributions.md <==
# uniform distribution errors informatively

    `min` and `max` must be numeric vectors of length 1
    They have class and length:
    `min`: numeric, 1
    `max`: logical, 1

---

    `min` and `max` must be numeric vectors of length 1
    They have class and length:
    `min`: numeric, 1
    `max`: function, 1

---

    `min` and `max` must be numeric vectors of length 1
    They have class and length:
    `min`: integer, 3
    `max`: numeric, 1

---

    `min` and `max` must finite scalars
    Their values are:
    `min`: -Inf
    `max`: Inf

---

    `max` must be greater than `min`
    Their values are:
    `min`: 1
    `max`: 1

# poisson() and binomial() error informatively in glm

    Wrong function name provided in another model
    It looks like you're using greta's `poisson()` function in the family argument of another model.
    Maybe you want to use `family = stats::poisson`,instead?

---

    Wrong function name provided in another model
    It looks like you're using greta's `binomial()` function in the family argument of another model.
    Maybe you want to use `family = stats::binomial`,instead?

---

    Wrong function name provided in another model
    It looks like you're using greta's `poisson()` function in the family argument of another model.
    Maybe you want to use `family = stats::poisson`,instead?

---

    Wrong function name provided in another model
    It looks like you're using greta's `poisson()` function in the family argument of another model.
    Maybe you want to use `family = stats::poisson`,instead?

# wishart distribution errors informatively

    `Sigma` must be a square 2D greta array
    However, `Sigma` has dimensions
    "3x3x3"

---

    `Sigma` must be a square 2D greta array
    However, `Sigma` has dimensions
    "3x2"

# lkj_correlation distribution errors informatively

    `eta` must be a positive scalar value, or a scalar <greta_array>

---

    `eta` must be a positive scalar value, or a scalar <greta_array>

---

    `eta` must be a scalar
    However `eta` had dimensions: 2, 1

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

# multivariate_normal distribution errors informatively

    the dimension of this distribution must be at least 2, but was 1
    multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    the dimension of this distribution must be at least 2, but was 1
    multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    Dimensions of parameters not compatible with multivariate distribution parameters of multivariate distributions cannot have more than two dimensions
    object `x` has dimensions: 3x3x3

---

    Not 2D square greta array
    x expected a 2D square greta array, but object `x` had dimension: 3x2

---

    distribution dimensions do not match implied dimensions
    The distribution dimension should be 3, but parameters implied dimensions: 3 vs 4
    Multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    the dimension of this distribution must be at least 2, but was 1
    multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    ! Could not evaluate cli `{}` expression: `n_realisations`.
    Caused by error in `eval(expr, envir = envir)`:
    ! object 'n_realisations' not found

---

    ! Could not evaluate cli `{}` expression: `n_realisations`.
    Caused by error in `eval(expr, envir = envir)`:
    ! object 'n_realisations' not found

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

# multinomial distribution errors informatively

    the dimension of this distribution must be at least 2, but was 1
    multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    ! Could not evaluate cli `{}` expression: `n_realisations`.
    Caused by error in `eval(expr, envir = envir)`:
    ! object 'n_realisations' not found

---

    ! Could not evaluate cli `{}` expression: `n_realisations`.
    Caused by error in `eval(expr, envir = envir)`:
    ! object 'n_realisations' not found

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

# categorical distribution errors informatively

    the dimension of this distribution must be at least 2, but was 1
    multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    ! Could not evaluate cli `{}` expression: `n_realisations`.
    Caused by error in `eval(expr, envir = envir)`:
    ! object 'n_realisations' not found

---

    ! Could not evaluate cli `{}` expression: `n_realisations`.
    Caused by error in `eval(expr, envir = envir)`:
    ! object 'n_realisations' not found

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

# dirichlet distribution errors informatively

    the dimension of this distribution must be at least 2, but was 1
    multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    ! Could not evaluate cli `{}` expression: `n_realisations`.
    Caused by error in `eval(expr, envir = envir)`:
    ! object 'n_realisations' not found

---

    ! Could not evaluate cli `{}` expression: `n_realisations`.
    Caused by error in `eval(expr, envir = envir)`:
    ! object 'n_realisations' not found

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

# dirichlet-multinomial distribution errors informatively

    the dimension of this distribution must be at least 2, but was 1
    multivariate distributions treat each row as a separate realisation - perhaps you need to transpose something?

---

    ! Could not evaluate cli `{}` expression: `n_realisations`.
    Caused by error in `eval(expr, envir = envir)`:
    ! object 'n_realisations' not found

---

    ! Could not evaluate cli `{}` expression: `n_realisations`.
    Caused by error in `eval(expr, envir = envir)`:
    ! object 'n_realisations' not found

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:

---

    `dimension` must be a positive scalar integer giving the dimension of the distribution
    `dim(target)` returns:
